-- ----------------------------
-- 公司基本信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_bat_article`;
CREATE TABLE `mortals_bat_article`
(
    `id`             bigint(20) NOT NULL AUTO_INCREMENT COMMENT '文章id',
    `title`          varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci DEFAULT NULL COMMENT '标题',
    `cover`          varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci DEFAULT NULL COMMENT '封面',
    `introduction`   varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci DEFAULT NULL COMMENT '文章介绍',
    `content`        text CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci COMMENT '内容',
    `content_html`   text CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci COMMENT '内容html',
    `author`         varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci DEFAULT NULL COMMENT '文章作者',
    `create_user_id` bigint(20)                                                    DEFAULT NULL COMMENT '创建用户',
    `create_time`    datetime                                                      DEFAULT NULL COMMENT '创建时间',
    `update_time`    datetime                                                      DEFAULT NULL COMMENT '更新时间',
    PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB
  DEFAULT CHARSET = utf8mb4
  COLLATE = utf8mb4_general_ci
  ROW_FORMAT = DYNAMIC COMMENT ='文章';


-- ----------------------------
-- 公司基本信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_bat_company`;
CREATE TABLE `mortals_bat_company`
(
    `id`             int(20) NOT NULL AUTO_INCREMENT COMMENT '公司id',
    `name`           varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci DEFAULT NULL COMMENT '名称',
    `introduction`   text CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci COMMENT '公司介绍',
    `phone`          varchar(20) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci  DEFAULT NULL COMMENT '电话号码',
    `address`        varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci DEFAULT NULL COMMENT '地址',
    `qr_code`        varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci DEFAULT NULL COMMENT '二维码',
    `create_user_id` bigint(20)                                                    DEFAULT NULL COMMENT '创建用户',
    `create_time`    datetime                                                      DEFAULT NULL COMMENT '创建时间',
    `update_time`    datetime                                                      DEFAULT NULL COMMENT '更新时间',
    PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB
  DEFAULT CHARSET = utf8mb4
  COLLATE = utf8mb4_general_ci
  ROW_FORMAT = DYNAMIC COMMENT ='公司基本信息';


-- ----------------------------
-- 产品分类表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_bat_category`;
CREATE TABLE `mortals_bat_category`
(
    `id`             bigint(20)                                              NOT NULL AUTO_INCREMENT COMMENT '主键ID，主键，自增长',
    `categoryCode`   varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '分类编码',
    `categoryName`   varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '分类名称',
    `parent_id`      bigint(20)                                                   DEFAULT NULL COMMENT '父分类ID，支持多级分类',
    `sort`           int(4)                                                  NULL DEFAULT 0 COMMENT '排序字段',
    `cover`          varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '封面',
    `remark`         varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '备注',
    `create_user_id` bigint(20)                                                   DEFAULT NULL COMMENT '创建用户',
    `create_time`    datetime                                                     DEFAULT NULL COMMENT '创建时间',
    `update_time`    datetime                                                     DEFAULT NULL COMMENT '更新时间',
    PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB
  CHARACTER SET = utf8
  COLLATE = utf8_general_ci COMMENT = '产品分类表';


-- ----------------------------
-- 产品分类筛选表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_bat_category_filters`;
CREATE TABLE `mortals_bat_category_filters`
(
    `id`             bigint(20)                                              NOT NULL AUTO_INCREMENT COMMENT '主键ID，主键，自增长',
    `category_id`      bigint(20)                                                   DEFAULT NULL COMMENT '分类ID',
    `categoryCode`   varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '分类编码',
    `categoryName`   varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '分类名称',
    `filter_name`          varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '筛选项名称',
    `remark`         varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '备注',
    `create_user_id` bigint(20)                                                   DEFAULT NULL COMMENT '创建用户',
    `create_time`    datetime                                                     DEFAULT NULL COMMENT '创建时间',
    `update_time`    datetime                                                     DEFAULT NULL COMMENT '更新时间',
    PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB
  CHARACTER SET = utf8
  COLLATE = utf8_general_ci COMMENT = '产品分类筛选表';


-- ----------------------------
-- 产品表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_bat_product`;
CREATE TABLE `mortals_bat_product`
(
    `id`             bigint(20)                                              NOT NULL AUTO_INCREMENT COMMENT '主键ID，主键，自增长',
    `productCode`    varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '产品编码',
    `productName`    varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '产品名称',
    `sort`           int(4)                                                  NULL DEFAULT 0 COMMENT '排序字段',
    `main_image_url` VARCHAR(500)                                            NOT NULL COMMENT '产品主图片',
    `description`    TEXT COMMENT '产品描述',
    `cover`          varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '封面',
    `remark`         varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '备注',
    `create_user_id` bigint(20)                                                   DEFAULT NULL COMMENT '创建用户',
    `create_time`    datetime                                                     DEFAULT NULL COMMENT '创建时间',
    `update_time`    datetime                                                     DEFAULT NULL COMMENT '更新时间',
    PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB
  CHARACTER SET = utf8
  COLLATE = utf8_general_ci COMMENT = '产品表';



-- ----------------------------
-- 产品规格表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_bat_product_specifications`;
CREATE TABLE `mortals_bat_product_specifications`
(
    `id`             bigint(20)                                              NOT NULL AUTO_INCREMENT COMMENT '主键ID，主键，自增长',
    `product_id`     bigint(20)                                                   DEFAULT NULL COMMENT '产品id',
    `productName`    varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '产品名称',
    `spec_name`    varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '规格名称',
    `spec_value`    varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '规格值',
    `sort`           int(4)                                                  NULL DEFAULT 0 COMMENT '排序字段',
    `description`    TEXT COMMENT '描述',
    `create_user_id` bigint(20)                                                   DEFAULT NULL COMMENT '创建用户',
    `create_time`    datetime                                                     DEFAULT NULL COMMENT '创建时间',
    `update_time`    datetime                                                     DEFAULT NULL COMMENT '更新时间',
    PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB
  CHARACTER SET = utf8
  COLLATE = utf8_general_ci COMMENT = '产品规格表';



-- ----------------------------
-- 产品文档表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_bat_product_documents`;
CREATE TABLE `mortals_bat_product_documents`
(
    `id`             bigint(20)                                              NOT NULL AUTO_INCREMENT COMMENT '主键ID，主键，自增长',
    `product_id`     bigint(20)                                                   DEFAULT NULL COMMENT '产品id',
    `productName`    varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '产品名称',
    `document_type` tinyint(2) NULL DEFAULT '0' COMMENT '文档类型，(0.Datasheet,1.Specification,2.User Guide,3.Other)',
    `document_name`    varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '文档名称',
    `document_path`    varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '文档地址',
    `sort`           int(4)                                                  NULL DEFAULT 0 COMMENT '排序字段',
    `remark`         varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '备注',
    `create_user_id` bigint(20)                                                   DEFAULT NULL COMMENT '创建用户',
    `create_time`    datetime                                                     DEFAULT NULL COMMENT '创建时间',
    `update_time`    datetime                                                     DEFAULT NULL COMMENT '更新时间',
    PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB
  CHARACTER SET = utf8
  COLLATE = utf8_general_ci COMMENT = '产品文档表';



-- ----------------------------
-- 产品媒体资源表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_bat_product_media`;
CREATE TABLE `mortals_bat_product_media`
(
    `id`             bigint(20)                                              NOT NULL AUTO_INCREMENT COMMENT '主键ID，主键，自增长',
    `product_id`     bigint(20)                                                   DEFAULT NULL COMMENT '产品id',
    `productName`    varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '产品名称',
    `media_type` tinyint(2) NULL DEFAULT '0' COMMENT '资源类型，(0.Image,1.Video)',
    `media_name`    varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '资源名称',
    `media_path`    varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '资源地址',
    `sort`           int(4)                                                  NULL DEFAULT 0 COMMENT '排序字段',
    `remark`         varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '备注',
    `create_user_id` bigint(20)                                                   DEFAULT NULL COMMENT '创建用户',
    `create_time`    datetime                                                     DEFAULT NULL COMMENT '创建时间',
    `update_time`    datetime                                                     DEFAULT NULL COMMENT '更新时间',
    PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB
  CHARACTER SET = utf8
  COLLATE = utf8_general_ci COMMENT = '产品文档表';


-- ----------------------------
-- 产品价格表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_bat_product_price`;
CREATE TABLE `mortals_bat_product_price`
(
    `id`             bigint(20)                                              NOT NULL AUTO_INCREMENT COMMENT '主键ID，主键，自增长',
    `product_id`     bigint(20)                                                   DEFAULT NULL COMMENT '产品id',
    `productName`    varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '产品名称',
    `price` DECIMAL(10,2) NOT NULL COMMENT '价格',
    `currency`    varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '货币类型',
    `stock_quantity`           int(4)                                                  NULL DEFAULT 0 COMMENT '库存数量',
    `purchase_link`         varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '购买链接',
    `remark`         varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '备注',
    `create_user_id` bigint(20)                                                   DEFAULT NULL COMMENT '创建用户',
    `create_time`    datetime                                                     DEFAULT NULL COMMENT '创建时间',
    `update_time`    datetime                                                     DEFAULT NULL COMMENT '更新时间',
    PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB
  CHARACTER SET = utf8
  COLLATE = utf8_general_ci COMMENT = '产品价格表';



-- ----------------------------
-- 产品评价表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_bat_product_price`;
CREATE TABLE `mortals_bat_product_price`
(
    `id`             bigint(20)                                              NOT NULL AUTO_INCREMENT COMMENT '主键ID，主键，自增长',
    `product_id`     bigint(20)                                                   DEFAULT NULL COMMENT '产品id',
    `productName`    varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '产品名称',
    `user_id`     bigint(20)                                                   DEFAULT NULL COMMENT '用户id',
    `rating`           int(4)                                                  NULL DEFAULT 0 COMMENT '评分（1-5）',
    `review_text`         varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '评价内容',
    `remark`         varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '备注',
    `create_user_id` bigint(20)                                                   DEFAULT NULL COMMENT '创建用户',
    `create_time`    datetime                                                     DEFAULT NULL COMMENT '创建时间',
    `update_time`    datetime                                                     DEFAULT NULL COMMENT '更新时间',
    PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB
  AUTO_INCREMENT = 10
  CHARACTER SET = utf8
  COLLATE = utf8_general_ci COMMENT = '产品价格表';


-- ----------------------------
-- 产品分类中间表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_bat_product_category`;
CREATE TABLE `mortals_bat_product_category`
(
    `id`             bigint(20)                                              NOT NULL AUTO_INCREMENT COMMENT '主键ID，主键，自增长',
    `category_id`    bigint(20)                                                   DEFAULT NULL COMMENT '分类id',
    `product_id`     bigint(20)                                                   DEFAULT NULL COMMENT '产品id',
    `productCode`    varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '产品编码',
    `productName`    varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '产品名称',
    `categoryCode`   varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '分类编码',
    `categoryName`   varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '分类名称',
    `remark`         varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '备注',
    `create_user_id` bigint(20)                                                   DEFAULT NULL COMMENT '创建用户',
    `create_time`    datetime                                                     DEFAULT NULL COMMENT '创建时间',
    `update_time`    datetime                                                     DEFAULT NULL COMMENT '更新时间',
    PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB
  AUTO_INCREMENT = 10
  CHARACTER SET = utf8
  COLLATE = utf8_general_ci COMMENT = '产品分类中间表';



-- ----------------------------
-- 产品图片表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_bat_product_images`;
CREATE TABLE `mortals_bat_product_images`
(
    `id`             bigint(20)                                              NOT NULL AUTO_INCREMENT COMMENT '主键ID，主键，自增长',
    `product_id`     bigint(20)                                                   DEFAULT NULL COMMENT '产品id',
    `image_url`      VARCHAR(500)                                            NOT NULL COMMENT '图片URL',
    `remark`         varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '备注',
    `create_user_id` bigint(20)                                                   DEFAULT NULL COMMENT '创建用户',
    `create_time`    datetime                                                     DEFAULT NULL COMMENT '创建时间',
    `update_time`    datetime                                                     DEFAULT NULL COMMENT '更新时间',
    PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB
  CHARACTER SET = utf8
  COLLATE = utf8_general_ci COMMENT = '产品图片表';



-- ----------------------------
-- 图片标签表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_bat_image_tags`;
CREATE TABLE `mortals_bat_image_tags`
(
    `id`             bigint(20)                                              NOT NULL AUTO_INCREMENT COMMENT '主键ID，主键，自增长',
    `image_id`     bigint(20)                                                   DEFAULT NULL COMMENT '关联的图片id',
    `tags`      VARCHAR(255)                                            NOT NULL COMMENT '标签名称',
    `remark`         varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '备注',
    `create_user_id` bigint(20)                                                   DEFAULT NULL COMMENT '创建用户',
    `create_time`    datetime                                                     DEFAULT NULL COMMENT '创建时间',
    `update_time`    datetime                                                     DEFAULT NULL COMMENT '更新时间',
    PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB
  CHARACTER SET = utf8
  COLLATE = utf8_general_ci COMMENT = '产品图片表';



-- ----------------------------
-- 案列表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_bat_example`;
CREATE TABLE `mortals_xhx_example`
(
    `id`             bigint(20) NOT NULL AUTO_INCREMENT COMMENT '案例id',
    `name`           varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci DEFAULT NULL COMMENT '案例名称',
    `example_type`   int(11)                                                       DEFAULT NULL COMMENT '案例种类（0，1，2，3，4，5）',
    `image1`         varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci DEFAULT NULL COMMENT '案例图片(1-16张)',
    `image2`         varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci DEFAULT NULL,
    `image3`         varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci DEFAULT NULL,
    `image4`         varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci DEFAULT NULL,
    `image5`         varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci DEFAULT NULL,
    `image6`         varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci DEFAULT NULL,
    `image7`         varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci DEFAULT NULL,
    `image8`         varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci DEFAULT NULL,
    `image9`         varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci DEFAULT NULL,
    `image10`        varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci DEFAULT NULL,
    `image11`        varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci DEFAULT NULL,
    `image12`        varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci DEFAULT NULL,
    `image13`        varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci DEFAULT NULL,
    `image14`        varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci DEFAULT NULL,
    `image15`        varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci DEFAULT NULL,
    `image16`        varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci DEFAULT NULL,
    `content`        text CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci COMMENT '内容',
    `content_html`   text CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci COMMENT '内容html',
    `create_user_id` bigint(20)                                                    DEFAULT NULL COMMENT '创建用户',
    `create_time`    datetime                                                      DEFAULT NULL COMMENT '创建时间',
    `update_time`    datetime                                                      DEFAULT NULL COMMENT '更新时间',
    PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB
  DEFAULT CHARSET = utf8mb4
  COLLATE = utf8mb4_general_ci
  ROW_FORMAT = DYNAMIC COMMENT ='案例图片';


-- ----------------------------
-- 轮播图片表
-- ----------------------------
CREATE TABLE `mortals_bat_slideshow`
(
    `id`             bigint(20) NOT NULL AUTO_INCREMENT COMMENT '轮播图id',
    `image_url`      varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci DEFAULT NULL COMMENT '图片地址',
    `introduction`   varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci DEFAULT NULL COMMENT '描述',
    `create_user_id` bigint(20)                                                    DEFAULT NULL COMMENT '创建用户',
    `create_time`    datetime                                                      DEFAULT NULL COMMENT '创建时间',
    `update_time`    datetime                                                      DEFAULT NULL COMMENT '更新时间',
    PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB
  DEFAULT CHARSET = utf8mb4
  COLLATE = utf8mb4_general_ci
  ROW_FORMAT = DYNAMIC COMMENT ='轮播';


CREATE TABLE `mortals_xhx_type`
(
    `id`             bigint(20) NOT NULL AUTO_INCREMENT COMMENT '电梯种类id',
    `type_name`      varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci DEFAULT '0' COMMENT '电梯种类名称',
    `create_user_id` bigint(20)                                                    DEFAULT NULL COMMENT '创建用户',
    `create_time`    datetime                                                      DEFAULT NULL COMMENT '创建时间',
    `update_time`    datetime                                                      DEFAULT NULL COMMENT '更新时间',
    PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB
  DEFAULT CHARSET = utf8mb4
  COLLATE = utf8mb4_general_ci
  ROW_FORMAT = DYNAMIC COMMENT ='类型';


CREATE TABLE `mortals_xhx_type_details`
(
    `id`             bigint(20) NOT NULL AUTO_INCREMENT COMMENT '种类详情id',
    `title`          varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci DEFAULT NULL COMMENT '标题',
    `image_url1`     varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci DEFAULT NULL COMMENT '图片',
    `image_url2`     varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci DEFAULT NULL,
    `image_url3`     varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci DEFAULT NULL,
    `image_url4`     varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci DEFAULT NULL,
    `image_url5`     varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci DEFAULT NULL,
    `type_id`        int(11)                                                       DEFAULT NULL COMMENT '产品类型id',
    `introduction`   text CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci COMMENT '描述内容',
    `create_user_id` bigint(20)                                                    DEFAULT NULL COMMENT '创建用户',
    `create_time`    datetime                                                      DEFAULT NULL COMMENT '创建时间',
    `update_time`    datetime                                                      DEFAULT NULL COMMENT '更新时间',
    PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB
  DEFAULT CHARSET = utf8mb4
  COLLATE = utf8mb4_general_ci
  ROW_FORMAT = DYNAMIC COMMENT ='类型详细';